/**
 * Copyright © 2025 IAV GmbH Ingenieurgesellschaft Auto und Verkehr, All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 */

import React, { useContext } from "react";
import "./header.css";
import "../css/globalColors.css";
import UserIcon from "../../assets/svg/userIcon";
import CompanyLogo from "../../assets/svg/companyLogo";
import SettingsIcon from "../../assets/svg/settingsIcon";
import { BLUE3, PADDING_GAB, WHITE } from "../../constants";
import { SettingsMenu } from "./settingsMenu";
import { UserMenu } from "./userMenu";
import { ColorSettingsContext } from "../../contexts/colorsettings";
import { AppLogoPlaceholder } from "../appLogoPlaceholder";
import HeaderIcon from "./headerIcon";
export const Header = props => {
  const menuRef = /*#__PURE__*/React.createRef();
  const userRef = /*#__PURE__*/React.createRef();
  const colorSettingsContext = useContext(ColorSettingsContext);
  const headerBackgroundColor = colorSettingsContext.currentColors.header.backgroundColor;
  const settingsIconColor = colorSettingsContext.currentColors.header.settingsIconColor;
  const userIconColor = colorSettingsContext.currentColors.header.userIconColor;
  const companyLogoDefault = props => /*#__PURE__*/React.createElement("div", {
    style: {
      display: props.headerOptions?.hideRight ? "none" : "flex",
      alignItems: "center",
      paddingRight: `${PADDING_GAB}px`
    }
  }, /*#__PURE__*/React.createElement(CompanyLogo, {
    fill: colorSettingsContext?.darkmode ? BLUE3 : WHITE
  }));
  const hideSettingsMenu = e => {
    if (e.key === "Escape") {
      menuRef.current?.hide(e);
    }
  };
  const hideUserMenu = e => {
    if (e.key === "Escape") {
      userRef.current?.hide(e);
    }
  };
  return /*#__PURE__*/React.createElement("div", {
    id: "header",
    className: (colorSettingsContext?.darkmode ? "bg-grey-5" : "bg-blue-0") + " flex justify-content-between align-items-center",
    style: {
      backgroundColor: headerBackgroundColor
    }
  }, /*#__PURE__*/React.createElement("div", {
    id: "left-element",
    className: "flex default-app-logo-text-style"
  }, props.headerOptions?.reactElementLeft ? props.headerOptions?.reactElementLeft : /*#__PURE__*/React.createElement(AppLogoPlaceholder, null)), /*#__PURE__*/React.createElement("div", {
    className: "flex justify-content-between align-items-center",
    id: "right-element"
  }, /*#__PURE__*/React.createElement(SettingsMenu, {
    ref: menuRef,
    hideMenu: hideSettingsMenu,
    menuOptions: props.settingsMenuOptions
  }), /*#__PURE__*/React.createElement(UserMenu, {
    ref: userRef,
    hideMenu: hideUserMenu,
    userMenuOptions: props.userMenuOptions
  }), /*#__PURE__*/React.createElement("div", {
    id: "right-element-user-section",
    className: "flex align-items-center justify-content-end"
  }, props.headerOptions?.headerElements?.map((headerElement, index) => {
    return /*#__PURE__*/React.createElement(React.Fragment, {
      key: index
    }, headerElement);
  }), /*#__PURE__*/React.createElement(HeaderIcon, {
    style: {
      margin: "0rem 1rem 0rem 1rem"
    },
    onClick: e => {
      if (menuRef.current) {
        menuRef.current.show(e);
      }
    },
    onKeyDown: e => hideSettingsMenu(e)
  }, /*#__PURE__*/React.createElement(SettingsIcon, {
    fill: settingsIconColor
  })), /*#__PURE__*/React.createElement(HeaderIcon, {
    style: {
      margin: "0rem 0rem 0rem 1rem"
    },
    onClick: e => {
      if (userRef.current) {
        userRef.current.show(e);
      }
    },
    onKeyDown: e => hideUserMenu(e)
  }, !props.headerOptions?.hideUserIcon && /*#__PURE__*/React.createElement(UserIcon, {
    fill: userIconColor
  }))), /*#__PURE__*/React.createElement("div", {
    id: "right-element-companylogo",
    className: "flex justify-content-end align-items-center"
  }, props.headerOptions?.reactElementRight ? props.headerOptions?.reactElementRight : companyLogoDefault(props))));
};